getFullName method
Returns a full name of this CQRS method, usually that is a fully qualified class name of the backend class.
Implementation
String getFullName() => fullName$;
Returns a full name of this CQRS method, usually that is a fully qualified class name of the backend class.
String getFullName() => fullName$;