VersionSupport class
- Annotations
-
- @ContractsSerializable.new()
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
platform
→ PlatformDTO
-
final
-
props
→ List<Object?>
-
The list of properties that will be used to determine whether
two instances are equal.
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
stringify
→ bool?
-
If set to
true, the toString method will be overridden to output
this instance's props.
no setterinherited
-
version
→ String
-
final
Methods
-
getFullName()
→ String
-
Returns a full name of this CQRS method, usually that is a fully
qualified class name of the backend class.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
resultFactory(dynamic decodedJson)
→ VersionSupportDTO
-
Returns a result of type
T deserialzied from the json.
-
toJson()
→ Map<String, dynamic>
-
Returns a JSON-encoded representation of the data this class carries.
-
toString()
→ String
-
A string representation of this object.
inherited